@@ -5,14 +5,13 @@ from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
 from slack_sdk.web.slack_response import SlackResponse
 
-from hartware_lib.exceptions.slack import ApiError
-from hartware_lib.settings.slack import SlackSettings
+from hartware_lib.settings import SlackBotSettings
 
 logger = logging.getLogger(__name__)
 
 
 class SlackAdapter:
-    def __init__(self, settings: SlackSettings):
+    def __init__(self, settings: SlackBotSettings):
         self.settings = settings
         self.client = WebClient(token=self.settings.api_token)
 
@@ -21,8 +20,7 @@ class SlackAdapter:
             return self.client.chat_postMessage(
                 channel=channel or self.settings.default_channel, text=message
             )
-        except SlackApiError:
-            api_error = ApiError()
-            logger.warning(api_error.message)
+        except SlackApiError as exc:
+            logger.warning(str(exc))
 
-            raise api_error
+            raise exc
